==> openGion_dev_5.3.4.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/table/TableFilter_SEQRESET.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.table;

import org.opengion.fukurou.util.StringUtil;
import org.opengion.hayabusa.db.AbstractTableFilter;
import org.opengion.hayabusa.db.DBTableModel;

/**
 * <p>TableFilter_SEQRESET は、TableFilter インターフェースを継承した、DBTableModel 処理用の
 * 実装クラスです。<br />
 *
 * ここでは、テーブルモデルのシーケンス項目の値を再セットしています。
 * シーケンスの値は、通常10ずつ増加しますが、BREAK_CLMが指定されており、
 * かつ、その項目の値がブレイクした場合は、100増加させます。
 * また、CLEAR_CLMが指定されている場合、そのカラムの値がキーブレイクした場合は、
 * シーケンス値を初期化(10)にします。
 *  SEQ_CLM   : シーケンス項目
 *  BREAK_CLM : キーブレイク項目(任意)
 *  CLEAR_CLM : シーケンス初期化項目
 *  INCREMENT : シーケンスの増分
 *  START_NO  : シーケンスの初期値
 *
 * @version  0.9.0  2000/10/17
 * @author   Hiroki Nakamura
 * @since    JDK1.1,
 */
public class TableFilter_SEQRESET extends AbstractTableFilter {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.3.7.0 (2009/06/01)" ;

	/**
	 * DBTableModel処理を実行します。<br />
	 * 
	 * @og.rev 4.3.7.0 (2009/06/01) 新規追加
	 *
	 * @return DBTableModel 処理後のテーブルモデル
	 */
	public DBTableModel execute() {
		int seqNo  = table.getColumnNo( getValue( "SEQ_CLM" ),false );
		int breakNo =  table.getColumnNo( getValue( "BREAK_CLM" ),false );
		int clearNo =  table.getColumnNo( getValue( "CLEAR_CLM" ),false );
		String increment =  getValue( "INCREMENT" );
		String start =  getValue( "START_NO" );

		if( seqNo < 0 ){ return table; }

		int seq = StringUtil.nval( start, 0 );
		int inc = StringUtil.nval( increment, 10 );
		String[] data = null;
		String preKey = "";
		String cleKey = "";
		for( int row = 0; row < rowNo.length; row ++ ) {
			data = table.getValues( rowNo[row] );

			if( clearNo >= 0 && cleKey != null && cleKey.length() > 0 && !cleKey.equals( data[clearNo] ) ) {
				seq = StringUtil.nval( start, 0 );
			}

			
			if( breakNo >= 0 && preKey != null && preKey.length() > 0 && !preKey.equals( data[breakNo] ) ) {
				seq += inc * 10;
			}
			else {
				seq += inc;
			}

			data[seqNo] = String.valueOf( seq );

			if( breakNo >= 0 ) {
				preKey = data[breakNo];
			}

			if( clearNo >= 0 ) {
				cleKey = data[clearNo];
			}
		}
		return table;
	}
}

==> openGion_dev_5.5.3.1.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/table/TableFilter_SEQRESET.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.table;

import org.opengion.fukurou.util.StringUtil;
import org.opengion.hayabusa.db.AbstractTableFilter;
import org.opengion.hayabusa.db.DBTableModel;

/**
 * <p>TableFilter_SEQRESET は、TableFilter インターフェースを継承した、DBTableModel 処理用の
 * 実装クラスです。<br />
 *
 * ここでは、テーブルモデルのシーケンス項目の値を再セットしています。
 * シーケンスの値は、通常10ずつ増加しますが、BREAK_CLMが指定されており、
 * かつ、その項目の値がブレイクした場合は、100増加させます。
 * また、CLEAR_CLMが指定されている場合、そのカラムの値がキーブレイクした場合は、
 * シーケンス値を初期化(10)にします。
 *  SEQ_CLM   : シーケンス項目
 *  BREAK_CLM : キーブレイク項目(任意)
 *  CLEAR_CLM : シーケンス初期化項目
 *  INCREMENT : シーケンスの増分
 *  START_NO  : シーケンスの初期値
 *
 * @version  0.9.0  2000/10/17
 * @author   Hiroki Nakamura
 * @since    JDK1.1,
 */
public class TableFilter_SEQRESET extends AbstractTableFilter {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.3.7.0 (2009/06/01)" ;

	/**
	 * DBTableModel処理を実行します。<br />
	 * 
	 * @og.rev 4.3.7.0 (2009/06/01) 新規追加
	 * @og.rev 5.5.2.6 (2012/05/25) protected変数を、private化したため、getterメソッドで取得するように変更
	 *
	 * @return DBTableModel 処理後のテーブルモデル
	 */
	public DBTableModel execute() {
		DBTableModel table = getDBTableModel();		// 5.5.2.6 (2012/05/25) インターフェースにgetterメソッド追加

		int seqNo  = table.getColumnNo( getValue( "SEQ_CLM" ),false );
		int breakNo =  table.getColumnNo( getValue( "BREAK_CLM" ),false );
		int clearNo =  table.getColumnNo( getValue( "CLEAR_CLM" ),false );
		String increment =  getValue( "INCREMENT" );
		String start =  getValue( "START_NO" );

		if( seqNo < 0 ){ return table; }

		int seq = StringUtil.nval( start, 0 );
		int inc = StringUtil.nval( increment, 10 );
		String[] data = null;
		String preKey = "";
		String cleKey = "";
		int[] rowNo = getParameterRows();					// 5.5.2.6 (2012/05/25) インターフェースにgetterメソッド追加
		for( int row = 0; row < rowNo.length; row ++ ) {
			data = table.getValues( rowNo[row] );

			if( clearNo >= 0 && cleKey != null && cleKey.length() > 0 && !cleKey.equals( data[clearNo] ) ) {
				seq = StringUtil.nval( start, 0 );
			}

			
			if( breakNo >= 0 && preKey != null && preKey.length() > 0 && !preKey.equals( data[breakNo] ) ) {
				seq += inc * 10;
			}
			else {
				seq += inc;
			}

			data[seqNo] = String.valueOf( seq );

			if( breakNo >= 0 ) {
				preKey = data[breakNo];
			}

			if( clearNo >= 0 ) {
				cleKey = data[clearNo];
			}
		}
		return table;
	}
}
